@@ -62,6 +62,10 @@ class JMan:
     def wms(self):
         return accions.Wms(con=self._con)
 
+    @property
+    def magatzems(self):
+        return accions.Magatzems(con=self._con)
+
 
 class JManFb:
     __slots__ = '_con'
